@@ -27,8 +27,10 @@ class MainWindow(QMainWindow):
 
 
 # use this function to execute
-def execute(Name = None, link='www.google.com'):
+def execute(Name = None, link=None):
     app = QApplication(sys.argv)
     QApplication.setApplicationName(Name)
     window = MainWindow(link)
     app.exec_()
+
+
